@@ -1,21 +1,21 @@
 // Copyright (c) Jupyter Development Team.
 // Distributed under the terms of the Modified BSD License.
 
-import { ISettingRegistry } from '@jupyterlab/settingregistry';
-import { ElementHandle, Page } from '@playwright/test';
-import {
-  IPluginNameToInterfaceMap,
-  PLUGIN_ID_SETTINGS
-} from '../inpage/tokens';
-import { MenuHelper } from './menu';
-import * as Utils from '../utils';
+import type { ISettingRegistry } from '@jupyterlab/settingregistry';
+import { ElementHandle, Locator, Page } from '@playwright/test';
+import type { IPluginNameToInterfaceMap } from '../extension';
 import { galata } from '../galata';
+import * as Utils from '../utils';
+import { MenuHelper } from './menu';
 
 /**
  * Sidebar helpers
  */
 export class SidebarHelper {
-  constructor(readonly page: Page, readonly menu: MenuHelper) {}
+  constructor(
+    readonly page: Page,
+    readonly menu: MenuHelper
+  ) {}
 
   /**
    * Whether a sidebar is opened or not
@@ -24,7 +24,7 @@ export class SidebarHelper {
    * @returns Opened status
    */
   isOpen = async (side: galata.SidebarPosition = 'left'): Promise<boolean> => {
-    return (await this.getContentPanel(side)) !== null;
+    return (await this.getContentPanelLocator(side).count()) > 0;
   };
 
   /**
@@ -34,10 +34,10 @@ export class SidebarHelper {
    * @returns Tab opened status
    */
   async isTabOpen(id: galata.SidebarTabId): Promise<boolean> {
-    const tabButton = await this.page.$(
+    const tabButton = this.page.locator(
       `${this.buildTabSelector(id)}.lm-mod-current`
     );
-    return tabButton !== null;
+    return (await tabButton.count()) > 0;
   }
 
   /**
@@ -114,19 +114,19 @@ export class SidebarHelper {
    * @param id Tab id
    */
   async toggleTabPosition(id: galata.SidebarTabId): Promise<void> {
-    const tab = await this.getTab(id);
+    const tab = this.getTabLocator(id);
 
-    if (!tab) {
+    if (!(await tab.count())) {
       return;
     }
 
     await tab.click({ button: 'right' });
 
-    const switchMenuItem = await this.page.waitForSelector(
-      '.lm-Menu-content .lm-Menu-item[data-command="sidebar:switch"]',
-      { state: 'visible' }
+    const switchMenuItem = this.page.locator(
+      '.lm-Menu-content .lm-Menu-item[data-command="sidebar:switch"]'
     );
-    if (switchMenuItem) {
+    await switchMenuItem.waitFor({ state: 'visible' });
+    if (await switchMenuItem.count()) {
       await switchMenuItem.click();
     }
   }
@@ -137,21 +137,31 @@ export class SidebarHelper {
   async moveAllTabsToLeft(): Promise<void> {
     await this.page.evaluate(
       async ({ pluginId }) => {
-        const settingRegistry = (await window.galataip.getPlugin(
+        const settingRegistry = (await window.galata.getPlugin(
           pluginId
         )) as ISettingRegistry;
-        const SIDEBAR_ID = '@jupyterlab/application-extension:sidebar';
-        const overrides = ((await settingRegistry.get(SIDEBAR_ID, 'overrides'))
-          .composite as any) as { [index: string]: any };
-        for (const widgetId of Object.keys(overrides)) {
-          overrides[widgetId] = 'left';
-        }
-        // default location of the property inspector and debugger is right, move it to left during tests
-        overrides['jp-property-inspector'] = 'left';
-        overrides['jp-debugger-sidebar'] = 'left';
-        await settingRegistry.set(SIDEBAR_ID, 'overrides', overrides as any);
+        const SHELL_ID = '@jupyterlab/application-extension:shell';
+        const sidebars = {
+          Debugger: 'left',
+          'Property Inspector': 'left',
+          'Extension Manager': 'left',
+          'File Browser': 'left',
+          'Sessions and Tabs': 'left',
+          'Table of Contents': 'left'
+        };
+        const currentLayout = (await settingRegistry.get(
+          SHELL_ID,
+          'layout'
+        )) as any;
+        await settingRegistry.set(SHELL_ID, 'layout', {
+          single: { ...currentLayout.single, ...sidebars },
+          multiple: { ...currentLayout.multiple, ...sidebars }
+        });
       },
-      { pluginId: PLUGIN_ID_SETTINGS as keyof IPluginNameToInterfaceMap }
+      {
+        pluginId:
+          '@jupyterlab/apputils-extension:settings' as keyof IPluginNameToInterfaceMap
+      }
     );
 
     await this.page.waitForFunction(() => {
@@ -165,11 +175,23 @@ export class SidebarHelper {
    *
    * @param id Tab id
    * @returns Tab handle
+   *
+   * @deprecated You should use locator instead {@link getTabLocator}
    */
   async getTab(
     id: galata.SidebarTabId
   ): Promise<ElementHandle<Element> | null> {
-    return await this.page.$(this.buildTabSelector(id));
+    return await this.getTabLocator(id).elementHandle();
+  }
+
+  /**
+   * Get the locator on a given tab
+   *
+   * @param id Tab id
+   * @returns Tab locator
+   */
+  getTabLocator(id: galata.SidebarTabId): Locator {
+    return this.page.locator(this.buildTabSelector(id));
   }
 
   /**
@@ -183,8 +205,8 @@ export class SidebarHelper {
       return;
     }
 
-    const tabButton = await this.page.$(this.buildTabSelector(id));
-    if (tabButton === null) {
+    const tabButton = this.getTabLocator(id);
+    if (!((await tabButton.count()) === 1)) {
       throw new Error(`Unable to find the tab ${id} button`);
     }
     await tabButton.click();
@@ -196,15 +218,51 @@ export class SidebarHelper {
    *
    * @param side Position
    * @returns Panel handle
+   *
+   * @deprecated You should use locator instead {@link getContentPanelLocator}
    */
   async getContentPanel(
     side: galata.SidebarPosition = 'left'
   ): Promise<ElementHandle<Element> | null> {
-    return await this.page.$(
-      `#jp-${side}-stack .p-StackedPanel-child:not(.lm-mod-hidden)`
+    return await this.getContentPanelLocator(side).elementHandle();
+  }
+
+  /**
+   * Get the locator on a sidebar content panel
+   *
+   * @param side Position
+   * @returns Panel handle
+   */
+  getContentPanelLocator(side: galata.SidebarPosition = 'left'): Locator {
+    return this.page.locator(
+      `#jp-${side}-stack .lm-StackedPanel-child:not(.lm-mod-hidden)`
     );
   }
 
+  /**
+   * Get the tab bar of the sidebar
+   *
+   * @param side Position
+   * @returns Tab bar handle
+   *
+   * @deprecated You should use locator instead {@link getTabBarLocator}
+   */
+  async getTabBar(
+    side: galata.SidebarPosition = 'left'
+  ): Promise<ElementHandle<Element> | null> {
+    return await this.getTabBarLocator(side).elementHandle();
+  }
+
+  /**
+   * Get the locator of the tab bar of the sidebar
+   *
+   * @param side Position
+   * @returns Tab bar locator
+   */
+  getTabBarLocator(side: galata.SidebarPosition = 'left'): Locator {
+    return this.page.locator(`.jp-SideBar.jp-mod-${side}`);
+  }
+
   /**
    * Open a given sidebar
    *
@@ -245,6 +303,45 @@ export class SidebarHelper {
     });
   }
 
+  /**
+   * Set the sidebar width
+   *
+   * @param width Sidebar width in pixels
+   * @param side Which sidebar to set: 'left' or 'right'
+   */
+  async setWidth(
+    width = 251,
+    side: galata.SidebarPosition = 'left'
+  ): Promise<boolean> {
+    if (!(await this.isOpen(side))) {
+      return false;
+    }
+
+    const handles = this.page.locator(
+      '#jp-main-split-panel > .lm-SplitPanel-handle:not(.lm-mod-hidden)'
+    );
+    const splitHandle =
+      side === 'left'
+        ? await handles.first().elementHandle()
+        : await handles.last().elementHandle();
+    const handleBBox = await splitHandle!.boundingBox();
+
+    await this.page.mouse.move(
+      handleBBox!.x + 0.5 * handleBBox!.width,
+      handleBBox!.y + 0.5 * handleBBox!.height
+    );
+    await this.page.mouse.down();
+    await this.page.mouse.move(
+      side === 'left'
+        ? 33 + width
+        : this.page.viewportSize()!.width - 33 - width,
+      handleBBox!.y + 0.5 * handleBBox!.height
+    );
+    await this.page.mouse.up();
+
+    return true;
+  }
+
   /**
    * Get the selector for a given tab
    *
@@ -256,15 +353,14 @@ export class SidebarHelper {
   }
 
   protected async _waitForTabActivate(
-    tab: ElementHandle<Element>,
+    tab: Locator,
     activate = true
   ): Promise<void> {
-    await this.page.waitForFunction(
-      ({ tab, activate }) => {
-        const current = tab.classList.contains('lm-mod-current');
-        return activate ? current : !current;
-      },
-      { tab, activate }
-    );
+    await Utils.waitForCondition(async () => {
+      const current = (await Utils.getLocatorClassList(tab)).includes(
+        'lm-mod-current'
+      );
+      return activate ? current : !current;
+    });
   }
 }
