@@ -7,7 +7,7 @@ import {
   IJupyterLabPageFixture,
   test
 } from '@jupyterlab/galata';
-import { positionMouseOver, setSidebarWidth } from './utils';
+import { positionMouseOver } from './utils';
 
 test.use({
   autoGoto: false,
@@ -31,7 +31,7 @@ test.describe('Debugger', () => {
 
     expect(
       await page.screenshot({
-        clip: { x: 1030, y: 62, width: 210, height: 28 }
+        clip: { x: 1015, y: 62, width: 225, height: 32 }
       })
     ).toMatchSnapshot('debugger_kernel.png');
   });
@@ -43,10 +43,10 @@ test.describe('Debugger', () => {
 
     await page.debugger.switchOn();
     await page.waitForCondition(() => page.debugger.isOpen());
-    await setSidebarWidth(page, 251, 'right');
+    await page.sidebar.setWidth(251, 'right');
 
     expect(
-      await page.screenshot({ clip: { y: 62, x: 780, width: 210, height: 28 } })
+      await page.screenshot({ clip: { y: 62, x: 765, width: 225, height: 32 } })
     ).toMatchSnapshot('debugger_activate.png');
   });
 
@@ -57,7 +57,7 @@ test.describe('Debugger', () => {
 
     await page.debugger.switchOn();
     await page.waitForCondition(() => page.debugger.isOpen());
-    await setSidebarWidth(page, 251, 'right');
+    await page.sidebar.setWidth(251, 'right');
 
     await setBreakpoint(page);
 
@@ -76,19 +76,21 @@ test.describe('Debugger', () => {
 
     await createNotebook(page);
 
-    const runButton = await page.waitForSelector(
-      '.jp-Toolbar-item >> [data-command="runmenu:run"]'
-    );
+    const runButton = await page
+      .locator('.jp-Toolbar-item')
+      .locator('[data-command="notebook:run-cell-and-select-next"]')
+      .getByRole('button');
 
     // Inject mouse pointer
     await page.evaluate(
       ([mouse]) => {
         document.body.insertAdjacentHTML('beforeend', mouse);
       },
-      [await positionMouseOver(runButton)]
+      [await positionMouseOver(runButton!)]
     );
-    await runButton.focus();
-    await runButton.hover();
+    await runButton!.focus();
+    await runButton!.focus();
+    await runButton!.hover();
 
     expect(
       await page.screenshot({ clip: { y: 62, x: 400, width: 190, height: 60 } })
@@ -102,7 +104,7 @@ test.describe('Debugger', () => {
 
     await page.debugger.switchOn();
     await page.waitForCondition(() => page.debugger.isOpen());
-    await setSidebarWidth(page, 251, 'right');
+    await page.sidebar.setWidth(251, 'right');
 
     await setBreakpoint(page);
 
@@ -118,7 +120,7 @@ test.describe('Debugger', () => {
       })
     ).toMatchSnapshot('debugger_stop_on_breakpoint.png');
 
-    await page.click('button[title^=Continue]');
+    await page.click('jp-button[title^=Continue]');
   });
 
   test('Breakpoints on exception', async ({ page, tmpPath }) => {
@@ -128,12 +130,12 @@ test.describe('Debugger', () => {
 
     await page.debugger.switchOn();
     await page.waitForCondition(() => page.debugger.isOpen());
-    await setSidebarWidth(page, 251, 'right');
+    await page.sidebar.setWidth(251, 'right');
 
-    await expect(page.locator('button.jp-PauseOnExceptions')).not.toHaveClass(
-      /lm-mod-toggled/
-    );
-    await page.locator('button.jp-PauseOnExceptions').click();
+    await expect(
+      page.locator('jp-button.jp-PauseOnExceptions')
+    ).toHaveAttribute('aria-pressed', 'false');
+    await page.locator('jp-button.jp-PauseOnExceptions').click();
     const menu = page.locator('.jp-PauseOnExceptions-menu');
     await expect(menu).toBeVisible();
     await expect(menu.locator('li.lm-Menu-item')).toHaveCount(3);
@@ -143,9 +145,9 @@ test.describe('Debugger', () => {
       .locator('li div.lm-Menu-itemLabel:text("userUnhandled")')
       .click();
 
-    await expect(page.locator('button.jp-PauseOnExceptions')).toHaveClass(
-      /lm-mod-toggled/
-    );
+    await expect(
+      page.locator('jp-button.jp-PauseOnExceptions')
+    ).toHaveAttribute('aria-pressed', 'true');
 
     await page.notebook.enterCellEditingMode(0);
     const keyboard = page.keyboard;
@@ -158,16 +160,22 @@ test.describe('Debugger', () => {
 
     // Wait to be stopped on the breakpoint
     await page.debugger.waitForCallStack();
+    // Wait for the red debug indicator box to appear
+    const firstCell = (await page.notebook.getCellLocator(0))!;
+    await firstCell.locator('.jp-DebuggerEditor-highlight').waitFor({
+      state: 'visible',
+      timeout: 1000
+    });
     expect(
       await page.screenshot({
         clip: { y: 110, x: 300, width: 300, height: 80 }
       })
     ).toMatchSnapshot('debugger_stop_on_unhandled_exception.png');
 
-    await page.click('button[title^=Continue]');
+    await page.click('jp-button[title^=Continue]');
     await page.notebook.waitForRun(0);
 
-    await page.locator('button.jp-PauseOnExceptions').click();
+    await page.locator('jp-button.jp-PauseOnExceptions').click();
 
     await expect(menu.locator('li.lm-Menu-item.lm-mod-toggled')).toHaveCount(1);
     await expect(
@@ -180,13 +188,22 @@ test.describe('Debugger', () => {
 
     // Wait to be stopped on the breakpoint
     await page.debugger.waitForCallStack();
+    // Wait for the red debug indicator box to appear
+    await firstCell.locator('.jp-DebuggerEditor-highlight').waitFor({
+      state: 'visible',
+      timeout: 1000
+    });
     expect(
       await page.screenshot({
         clip: { y: 110, x: 300, width: 300, height: 80 }
       })
     ).toMatchSnapshot('debugger_stop_on_raised_exception.png');
-    await page.click('button[title^=Continue]');
-    await page.click('button[title^=Continue]');
+    await page.click('jp-button[title^=Continue]'); // Pauses as the error is raised (try block)
+    await page.debugger.waitForCallStack();
+    await page.click('jp-button[title^=Continue]'); // Pauses as the error is raised (catch block)
+    await page.debugger.waitForCallStack();
+    await page.click('jp-button[title^=Continue]'); // Pauses again as the error is unhandled
+    await page.notebook.waitForRun(0);
   });
 
   test('Debugger sidebar', async ({ page, tmpPath }) => {
@@ -194,11 +211,10 @@ test.describe('Debugger', () => {
 
     await createNotebook(page);
 
-    const sidebar = await page.waitForSelector(
-      '[data-id="jp-debugger-sidebar"]'
-    );
+    const sidebar = page.locator('[data-id="jp-debugger-sidebar"]');
+    await sidebar.waitFor();
     await sidebar.click();
-    await setSidebarWidth(page, 251, 'right');
+    await page.sidebar.setWidth(251, 'right');
 
     // Inject mouse pointer
     await page.evaluate(
@@ -222,7 +238,7 @@ test.describe('Debugger', () => {
 
     await page.debugger.switchOn();
     await page.waitForCondition(() => page.debugger.isOpen());
-    await setSidebarWidth(page, 251, 'right');
+    await page.sidebar.setWidth(251, 'right');
 
     await setBreakpoint(page);
 
@@ -249,7 +265,7 @@ test.describe('Debugger', () => {
 
     await page.debugger.switchOn();
     await page.waitForCondition(() => page.debugger.isOpen());
-    await setSidebarWidth(page, 251, 'right');
+    await page.sidebar.setWidth(251, 'right');
 
     await setBreakpoint(page);
 
@@ -270,7 +286,7 @@ test.describe('Debugger', () => {
       path: 'test/documentation/screenshots/debugger-callstack.png'
     });
 
-    await page.click('button[title^=Continue]');
+    await page.click('jp-button[title^=Continue]');
   });
 
   test('Breakpoints panel', async ({ page, tmpPath }) => {
@@ -280,7 +296,7 @@ test.describe('Debugger', () => {
 
     await page.debugger.switchOn();
     await page.waitForCondition(() => page.debugger.isOpen());
-    await setSidebarWidth(page, 251, 'right');
+    await page.sidebar.setWidth(251, 'right');
 
     await setBreakpoint(page);
 
@@ -290,7 +306,7 @@ test.describe('Debugger', () => {
     // Wait to be stopped on the breakpoint
     await page.debugger.waitForCallStack();
 
-    const breakpointsPanel = await page.debugger.getBreakPointsPanel();
+    const breakpointsPanel = await page.debugger.getBreakPointsPanelLocator();
     expect(await breakpointsPanel.innerText()).toMatch(/ipykernel.*\/\d+.py/);
 
     // Don't compare screenshot as the kernel id varies
@@ -300,7 +316,7 @@ test.describe('Debugger', () => {
       path: 'test/documentation/screenshots/debugger-breakpoints.png'
     });
 
-    await page.click('button[title^=Continue]');
+    await page.click('jp-button[title^=Continue]');
   });
 
   test('Source panel', async ({ page, tmpPath }) => {
@@ -310,7 +326,7 @@ test.describe('Debugger', () => {
 
     await page.debugger.switchOn();
     await page.waitForCondition(() => page.debugger.isOpen());
-    await setSidebarWidth(page, 251, 'right');
+    await page.sidebar.setWidth(251, 'right');
 
     await setBreakpoint(page);
 
@@ -319,12 +335,9 @@ test.describe('Debugger', () => {
 
     // Wait to be stopped on the breakpoint
     await page.debugger.waitForCallStack();
-
-    await expect(
-      page.locator(
-        '[aria-label="side panel content"] >> text=Source/tmp/ipykernel_'
-      )
-    ).toBeVisible();
+    await expect(page.locator('.jp-DebuggerSources-header-path')).toContainText(
+      '/tmp/ipykernel_'
+    );
 
     // Don't compare screenshot as the kernel id varies
     // Need to set precisely the path
@@ -333,16 +346,16 @@ test.describe('Debugger', () => {
       path: 'test/documentation/screenshots/debugger-source.png'
     });
 
-    await page.click('button[title^=Continue]');
+    await page.click('jp-button[title^=Continue]');
   });
 });
 
 async function createNotebook(page: IJupyterLabPageFixture) {
   await page.notebook.createNew();
 
-  await setSidebarWidth(page);
+  await page.sidebar.setWidth();
 
-  await page.waitForSelector('text=Python 3 (ipykernel) | Idle');
+  await page.locator('text=Python 3 (ipykernel) | Idle').waitFor();
 }
 
 async function setBreakpoint(page: IJupyterLabPageFixture) {
