@@ -13,7 +13,9 @@ test.describe('Completer', () => {
       await page.notebook.createNew(fileName);
     });
 
-    test('Open completer on notebook', async ({ page }) => {
+    test('Open completer on notebook and accept suggestion', async ({
+      page
+    }) => {
       await page.notebook.setCell(
         0,
         'code',
@@ -35,7 +37,22 @@ test.describe('Completer', () => {
       completer = page.locator(COMPLETER_SELECTOR);
       await completer.waitFor();
       const imageName = 'completer.png';
-      expect(await completer.screenshot()).toMatchSnapshot(imageName);
+      expect.soft(await completer.screenshot()).toMatchSnapshot(imageName);
+      // Accept the completion
+      await page.keyboard.press('Enter');
+      const textAfter = await page.notebook.getCellTextInput(1);
+      expect(textAfter).toBe('option_1');
+      // Completer shouldn't show up, but Completer should be enabled
+      await page.keyboard.press('Enter');
+      await page.keyboard.press('Tab');
+      let locator = page.locator(
+        '.lm-Widget.jp-mod-active .jp-CodeMirrorEditor.jp-InputArea-editor'
+      );
+      await expect(locator).toHaveCount(1);
+      await expect(locator).toHaveClass(/jp-mod-completer-enabled/);
+      completer = page.locator(COMPLETER_SELECTOR);
+
+      await expect(completer).toBeHidden();
     });
 
     test('Show documentation panel', async ({ page, tmpPath }) => {
@@ -82,10 +99,9 @@ test.describe('Completer', () => {
       await page.keyboard.press('Tab');
       completer = page.locator(COMPLETER_SELECTOR);
       await completer.waitFor();
-      await page.waitForSelector('.jp-Completer-loading-bar');
-      await page.waitForSelector('.jp-Completer-loading-bar', {
-        state: 'detached'
-      });
+      await page
+        .locator('.jp-Completer-loading-bar')
+        .waitFor({ state: 'detached' });
       await session?.detach();
       const imageName = 'completer-with-doc-panel.png';
       expect(await completer.screenshot()).toMatchSnapshot(imageName);
@@ -158,8 +174,8 @@ test.describe('Completer', () => {
 
       await page.click('button:has-text("Select")');
 
-      await page.waitForSelector('[aria-label="Code Cell Content"]');
-      await page.waitForSelector('text=| Idle');
+      await page.locator('[aria-label="Code Cell Content"]').waitFor();
+      await page.locator('text=| Idle').waitFor();
 
       await page.keyboard.type('import getopt\ngetopt.');
       await page.keyboard.press('Tab');
